<?php

/**
 * Theme admin functions.
 *
 * @package Everse
 */
if ( !defined( 'ABSPATH' ) ) {
    exit( 'Direct script access denied.' );
}
/**
* Add admin menu
*
* @since 1.0.0
*/
function everse_theme_admin_menu()
{
    add_theme_page(
        __( 'Everse Getting Started', 'everse' ),
        __( 'Everse', 'everse' ),
        'manage_options',
        'everse-theme',
        'everse_admin_page_content',
        30
    );
}

add_action( 'admin_menu', 'everse_theme_admin_menu' );
/**
* Add admin page content
*
* @since 1.0.0
*/
function everse_admin_page_content()
{
    $docs_url = 'https://docs.deothemes.com/everse/knowledgebase/';
    $urls = array(
        'docs'                      => 'https://docs.deothemes.com/everse',
        'header-footer-builder'     => $docs_url . 'header-footer-builder',
        'woocommerce-builder'       => $docs_url . 'woocommerce-builder',
        'advanced-customization'    => $docs_url . 'advanced-customization',
        'importing-pro-templates'   => $docs_url . 'importing-pro-templates',
        'advanced-woocommerce'      => $docs_url . 'advanced-woocommerce',
        'premium-elementor-widgets' => $docs_url . 'premium-elementor-widgets',
        'dynamic-custom-post-types' => $docs_url . 'dynamic-custom-post-types',
        'learndash-integration'     => $docs_url . 'learndash-integration',
        'adobe-fonts-integration'   => $docs_url . 'adobe-fonts-integration',
        'page-layouts'              => $docs_url . 'page-layouts',
        'acf-pro'                   => $docs_url . 'acf-pro-included',
        'gdpr'                      => $docs_url . 'gdpr-tools',
    );
    $buttons = array(
        'logo'          => array(
        'link_url'  => admin_url( 'customize.php?autofocus[section]=everse_settings_logo' ),
        'link_text' => __( 'Logo', 'everse' ),
        'icon'      => 'dashicons dashicons-format-image',
    ),
        'header'        => array(
        'link_url'  => admin_url( 'customize.php?autofocus[panel]=everse_settings_header' ),
        'link_text' => __( 'Header', 'everse' ),
        'icon'      => 'dashicons dashicons-align-center',
    ),
        'footer'        => array(
        'link_url'  => admin_url( 'customize.php?autofocus[section]=everse_settings_footer' ),
        'link_text' => __( 'Footer', 'everse' ),
        'icon'      => 'dashicons dashicons-align-full-width',
    ),
        'layout'        => array(
        'link_url'  => admin_url( 'customize.php?autofocus[panel]=everse_settings_layout' ),
        'link_text' => __( 'Layout', 'everse' ),
        'icon'      => 'dashicons dashicons-layout',
    ),
        'colors'        => array(
        'link_url'  => admin_url( 'customize.php?autofocus[panel]=everse_settings_colors' ),
        'link_text' => __( 'Colors', 'everse' ),
        'icon'      => 'dashicons dashicons-admin-appearance',
    ),
        'typography'    => array(
        'link_url'  => admin_url( 'customize.php?autofocus[panel]=everse_settings_typography' ),
        'link_text' => __( 'Typography', 'everse' ),
        'icon'      => 'dashicons dashicons-editor-textcolor',
    ),
        'customizer'    => array(
        'link_url'  => admin_url( 'customize.php' ),
        'link_text' => __( 'Customizer', 'everse' ),
        'icon'      => 'dashicons dashicons-admin-generic',
    ),
        'documentation' => array(
        'link_url'  => 'https://docs.deothemes.com/everse',
        'link_text' => __( 'Documentation', 'everse' ),
        'icon'      => 'dashicons dashicons-book-alt',
    ),
        'support'       => array(
        'link_url'  => admin_url( 'themes.php?page=everse-theme-contact' ),
        'link_text' => __( 'Support', 'everse' ),
        'icon'      => 'dashicons dashicons-sos',
    ),
    );
    
    if ( everse_fs()->can_use_premium_code__premium_only() && defined( 'EVERSE_CORE_VERSION' ) ) {
        $buttons['theme_templates'] = array(
            'link_url'  => admin_url( 'edit.php?post_type=theme_template' ),
            'link_text' => __( 'Theme Templates', 'everse' ),
            'icon'      => 'dashicons dashicons-table-row-after',
        );
        $buttons['adobe_fonts'] = array(
            'link_url'  => admin_url( 'admin.php?page=everse-core-custom-typekit-fonts' ),
            'link_text' => __( 'Adobe Fonts', 'everse' ),
            'icon'      => 'dashicons dashicons-editor-spellcheck',
        );
        $buttons['integrations'] = array(
            'link_url'  => admin_url( 'admin.php?page=everse-core-integrations' ),
            'link_text' => __( 'Google Map', 'everse' ),
            'icon'      => 'dashicons dashicons-location-alt',
        );
    }
    
    $videos = array(
        'theme-installation'    => array(
        'links' => array( array(
        'link_url'     => 'https://www.youtube.com/watch?v=RLBLXImKADY&list=PLaPNmyRO67T2UNhQYY8c6RLskRX8iMtOR&ab_channel=DeoThemes',
        'link_text'    => __( 'Theme Installation', 'everse' ),
        'link_img_src' => EVERSE_URI . '/assets/admin/img/videos/everse_video_theme_installation.jpg',
    ) ),
    ),
        'colors-editing'        => array(
        'links' => array( array(
        'link_url'     => 'https://www.youtube.com/watch?v=vC-rp-uewro&list=PLaPNmyRO67T2UNhQYY8c6RLskRX8iMtOR&index=2&ab_channel=DeoThemes',
        'link_text'    => __( 'Colors Editing', 'everse' ),
        'link_img_src' => EVERSE_URI . '/assets/admin/img/videos/everse_video_colors_editing.jpg',
    ) ),
    ),
        'fonts-editing'         => array(
        'links' => array( array(
        'link_url'     => 'https://www.youtube.com/watch?v=SDPd4NKa8xk&list=PLaPNmyRO67T2UNhQYY8c6RLskRX8iMtOR&index=3&t=1s&ab_channel=DeoThemes',
        'link_text'    => __( 'Fonts Editing', 'everse' ),
        'link_img_src' => EVERSE_URI . '/assets/admin/img/videos/everse_video_fonts_editing.jpg',
    ) ),
    ),
        'header-footer-builder' => array(
        'links' => array( array(
        'link_url'     => 'https://www.youtube.com/watch?v=_Z-gaaFtqSk&list=PLaPNmyRO67T2UNhQYY8c6RLskRX8iMtOR&index=4&ab_channel=DeoThemes',
        'link_text'    => __( 'Header / Footer Builder', 'everse' ),
        'link_img_src' => EVERSE_URI . '/assets/admin/img/videos/everse_video_header_builder.jpg',
    ) ),
    ),
        'product-builder'       => array(
        'links' => array( array(
        'link_url'     => 'https://www.youtube.com/watch?v=NkjZeNwvbp8&list=PLaPNmyRO67T2UNhQYY8c6RLskRX8iMtOR&index=5&ab_channel=DeoThemes',
        'link_text'    => __( 'Product Builder', 'everse' ),
        'link_img_src' => EVERSE_URI . '/assets/admin/img/videos/everse_video_product_builder.jpg',
    ) ),
    ),
    );
    $info = array(
        'header-footer-builder'     => array(
        'title'     => __( 'Header / Footer Builder', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['header-footer-builder'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['header-footer-builder'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'woocommerce-builder'       => array(
        'title'     => __( 'WooCommerce Builder', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['woocommerce-builder'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['woocommerce-builder'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'advanced-customization'    => array(
        'title'     => __( 'Advanced Customization', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['advanced-customization'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['advanced-customization'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'importing-pro-templates'   => array(
        'title'     => __( 'Pro Demos', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['importing-pro-templates'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['importing-pro-templates'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'advanced-woocommerce'      => array(
        'title'     => __( 'Advanced WooCommerce', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['advanced-woocommerce'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['advanced-woocommerce'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'premium-elementor-widgets' => array(
        'title'     => __( 'Premium Elementor Widgets', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['premium-elementor-widgets'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['premium-elementor-widgets'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'dynamic-custom-post-types' => array(
        'title'     => __( 'Dynamic Custom Post Types', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['dynamic-custom-post-types'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['dynamic-custom-post-types'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'learndash-integration'     => array(
        'title'     => __( 'LearnDash Integration', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['learndash-integration'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['learndash-integration'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'adobe-fonts-integration'   => array(
        'title'     => __( 'Adobe Fonts Integration', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['adobe-fonts-integration'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['adobe-fonts-integration'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'page-layouts'              => array(
        'title'     => __( 'Page Layouts', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['page-layouts'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['page-layouts'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'acf-pro'                   => array(
        'title'     => __( 'ACF Pro Included', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['acf-pro'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['acf-pro'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
        'gdpr'                      => array(
        'title'     => __( 'GDPR Tools', 'everse' ),
        'class'     => 'everse-addon-list-item',
        'title_url' => $urls['gdpr'],
        'links'     => array( array(
        'link_class'   => 'everse-learn-more',
        'link_url'     => $urls['gdpr'],
        'link_text'    => __( 'Learn More &#187;', 'everse' ),
        'target_blank' => true,
    ) ),
    ),
    );
    ?>
		<div class="everse-page-header">
			<div class="everse-page-header__container">
				<div class="everse-page-header__branding">
					<img src="<?php 
    echo  esc_url( EVERSE_URI . '/assets/admin/img/everse_logo.png' ) ;
    ?>" class="everse-page-header__logo" alt="Everse">
					<span class="everse-theme-version"><?php 
    echo  esc_html( EVERSE_VERSION ) ;
    ?></span>
				</div>
				<div class="everse-page-header__tagline">
					<span class="everse-page-header__tagline-text"><?php 
    echo  esc_html__( 'Visual Website Builder Tool', 'everse' ) ;
    ?></span>					
				</div>				
			</div>
		</div>

		<div class="wrap everse-container">

			<div class="everse-grid">

				<div class="everse-grid-content">
					<div class="everse-body">
						<h1 class="everse-title"><?php 
    esc_html_e( 'Welcome to Everse!', 'everse' );
    ?></h1>
						<p class="everse-intro-text">
							<?php 
    echo  esc_html__( 'Everse is now installed and ready to use. Get ready to build something beautiful. To get started check the links below. We hope you enjoy it!', 'everse' ) ;
    ?>
						</p>

						<ul class="everse-navigation-buttons">
							<?php 
    foreach ( $buttons as $button => $link ) {
        echo  '<li class="everse-navigation-buttons__item">' ;
        echo  '<a href="' . esc_url( $link['link_url'] ) . '" class="everse-navigation-buttons__url" target="_blank">' ;
        echo  '<span class="everse-navigation-buttons__icon ' . esc_attr( $link['icon'] ) . '"></span>' ;
        echo  '<span class="everse-navigation-buttons__label">' . esc_html( $link['link_text'] ) . '</span>' ;
        echo  '</a>' ;
        echo  '</li>' ;
    }
    ?>							
						</ul>
					</div> <!-- .everse-body -->			

					<div class="everse-postbox">
						
						<?php 
    ?>
							<h2 class="everse-addon-title"><?php 
    echo  esc_html__( 'More features with Everse Pro', 'everse' ) ;
    ?></h2>
						<?php 
    ?>

						<ul class="everse-addon-list">
							<?php 
    foreach ( (array) $info as $addon => $info ) {
        $title_url = ( isset( $info['title_url'] ) && !empty($info['title_url']) ? 'href="' . esc_url( $info['title_url'] ) . '"' : '' );
        $anchor_target = ( isset( $info['title_url'] ) && !empty($info['title_url']) ? 'target="_blank" rel="noopener"' : '' );
        echo  '<li class="' . esc_attr( $info['class'] ) . '"><a class="everse-addon-item-title"' . $title_url . $anchor_target . ' >' . esc_html( $info['title'] ) . '</a><div class="everse-addon-link-wrapper">' ;
        foreach ( $info['links'] as $key => $link ) {
            printf(
                '<a class="%1$s" %2$s %3$s> %4$s </a>',
                esc_attr( $link['link_class'] ),
                ( isset( $link['link_url'] ) ? 'href="' . esc_url( $link['link_url'] ) . '"' : '' ),
                ( isset( $link['target_blank'] ) && $link['target_blank'] ? 'target="_blank" rel="noopener"' : '' ),
                // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
                esc_html( $link['link_text'] )
            );
        }
        echo  '</div></li>' ;
    }
    ?>
						</ul>
					</div>
				</div> <!-- .content -->

				<aside class="everse-grid-sidebar">
					<div class="everse-grid-sidebar-widget-area">
						<div class="everse-widget-video-tutorials">
							<h2 class="everse-sidebar-title"><?php 
    esc_html_e( 'Video Tutorials', 'everse' );
    ?></h2>
							<ul class="everse-video-tutorials">
								<?php 
    foreach ( (array) $videos as $video => $info ) {
        echo  '<li class="everse-video-tutorials__item">' ;
        foreach ( $info['links'] as $key => $link ) {
            echo  '<a href="' . esc_url( $link['link_url'] ) . '" class="everse-video-tutorials__url" target="_blank" rel="noopener">' ;
            echo  '<img src="' . esc_url( $link['link_img_src'] ) . '" alt="' . esc_html( $link['link_text'] ) . '" class="everse-video-tutorials__img" />' ;
            echo  '<span class="everse-video-tutorials__label">' . esc_html( $link['link_text'] ) . '</span>' ;
            echo  '</a>' ;
        }
        echo  '</li>' ;
    }
    ?>
							</ul>
							<div class="everse-widget-video-tutorials__more-videos">
								<a href="https://www.youtube.com/watch?v=RLBLXImKADY&list=PLaPNmyRO67T2UNhQYY8c6RLskRX8iMtOR&ab_channel=DeoThemes" class="button" target="_blank"><?php 
    esc_html_e( 'More Videos', 'everse' );
    ?></a>
							</div>												
						</div>						
					</div>					
				</aside>	

			</div> <!-- .grid -->		
			
		</div>
	<?php 
}

/**
* Change theme icon
*
* @since 1.0.0
*/
function everse_fs_custom_icon()
{
    return EVERSE_DIR . '/assets/admin/img/theme-icon.jpg';
}

everse_fs()->add_filter( 'plugin_icon', 'everse_fs_custom_icon' );
/**
 * Add extra permissions to Freemius
 */
function everse_freemius_extra_permissions( $permissions )
{
    $permissions['newsletter'] = array(
        'icon-class' => 'dashicons dashicons-email-alt',
        'label'      => everse_fs()->get_text_inline( 'Newsletter', 'everse' ),
        'desc'       => everse_fs()->get_text_inline( 'Your email is added to our newsletter. Updates, announcements, marketing, no spam. Unsubscribe anytime.', 'everse' ),
        'priority'   => 15,
    );
    return $permissions;
}

everse_fs()->add_filter( 'permission_list', 'everse_freemius_extra_permissions' );